@@ -164,7 +164,7 @@ def gen_class_h(bdir, data):
 	fname = '%s/include/konoha/gen/konoha_class_.h' % bdir
 	f = open_h(fname, ['<konoha/konoha_t.h>'] + data.INCLUDE_H)
 
-	write_define(f, 'KONOHA_SERIAL_NUMBER', '%d' % data.serial_number)
+	write_define(f, 'KONOHA_BUILDID', '%d' % data.serial_number)
 	write_dline(f)
 	for u in data.USING_MAP:
 		write_ifndefine(f, 'KONOHA_USING_%s' % u.upper(), '1')
@@ -241,6 +241,11 @@ def gen_class_h(bdir, data):
 		cn += 1
 	write_define(f, 'KNH_TMETHODFIELD_SIZE', '%d' % cn, 32)
 	
+	cn = 1
+	for n in data.EXPT_LIST:
+		write_define(f, 'EXPT_%s' % n, '%d' % cn, 32)
+		cn += 1
+	
 	write_chapter(f, '[KNH_CLASS_T]')
 	
 	for c in data.CLASS_LIST:
@@ -443,13 +448,13 @@ def write_method_c(f, mtd, data):
 
 def C(t):
 	if t[0] == 'p': t = t[1:]
-	if t.endswith(".."): return "Iterator"
-	if t.endswith("[]"): return "Array"
+	if t.endswith("..") or t.endswith("..!") : return "Iterator"
+	if t.endswith("[]") or t.endswith("[]!"): return "Array"
 	return t.replace("!", "")
 
 def CI(t):
 	if t[0] == 'p': t = t[1:]
-	return t.replace("!", "").replace("..", "").replace("[]", "")
+	return t.replace("!", "").replace("..", "__").replace("[]", "__A")
 
 def write_tmapper_c(f, mm, data):
 	if mm.mapfunc == None: return
@@ -466,6 +471,14 @@ void KNH_TMAPPER_%s_%s(
 }
 ''' %(CI(mm.fcname), CI(mm.tcname), C(mm.tcname), C(mm.fcname)))
 
+def CLASS_cname2(cname):
+	cname = cname.replace("!", "")
+	if cname.endswith("[]") :
+		return 'ACLASS_%s' % cname.replace("[]", "")
+	if cname.endswith("..") :
+		return 'ICLASS_%s' % cname.replace("..", "")
+	return 'CLASS_%s' % cname
+	
 def write_mapmap_c(f, mm, data):
 	if mm.mapfunc == None: return
 	f.write('''
@@ -474,7 +487,7 @@ def write_mapmap_c(f, mm, data):
 \t\t%s, %s,  
 \t\t%s, %s
 \t);
-''' % (CI(mm.fcname), CI(mm.tcname), mm.make_flag(data), CLASS_cname(mm.fcname), CLASS_cname(mm.tcname), mm.mapfunc, mm.mapopt))
+''' % (CI(mm.fcname), CI(mm.tcname), mm.make_flag(data), CLASS_cname2(mm.fcname), CLASS_cname2(mm.tcname), mm.mapfunc, mm.mapopt))
 
 def write_method_func_c(f, mtd, data):
 	if mtd.methodfunc != None: return
@@ -540,7 +553,7 @@ METHOD %s(Ctx *ctx, knh_sfp_t *sfp)
 }
 ''' % (rmap, rval))
 
-def gen_class_c(bdir, p, data):
+def gen_class2_c(bdir, p, data):
 	fname = '%s/konoha/gen/package/%s_.c' % (bdir, p.pname)
 	f = open_c(fname, ['<konoha/konoha_dev.h>'])
 	write_chapter(f, '[flag]')
@@ -641,6 +654,11 @@ void konoha_class_init0(Ctx *ctx)
 			f.write('''
 	KNH_XCLASS(ctx, CLASS_%s, CLASS_%s, %s(ctx, CLASS_%s, CLASS_%s, NULL));''' % (cname, bcname, func, bcname, cname))
 	
+	for cname in data.EXPT_LIST:
+		e = data.EXPT_MAP[cname]
+		f.write('''
+	KNH_TEXPT(ctx, %s, EXPT_%s, new_String__T(NULL, "%s"), %s);''' % (e.make_flag(data), cname, cname, e.parent))
+	
 	f.write('''
 #ifdef KONOHA_MONOLITHIC
 ''')
