@@ -116,10 +116,10 @@ TOKEN = '''
 &= bitande       
 ?\?= ALTLET      
 ? QUESTION       @P2
-.. SUBSETE       @P2
-..< SUBSET       @P2
-..+ OFFSET       @P2
-: COLON          @P2
+.. Itr           @op @P2 @A1
+..< SUBSET       @P99
+..+ OFFSET       @P99
+: COLON          @P99
 ?\? ALT          @op    @P2
 
 || OR            @P5
@@ -146,6 +146,7 @@ to? To                 @op @A2  @P9
 <= Lte                 @op @A2   @P9
 > Gt                   @op @A2   @P9
 >= Gte                 @op @A2   @P9
+=~  Match              @op @A2   @P9
 
 |  Lor                  @op @top  @P11
 %% Fmt                 @op @2    @P12 @A2
