@@ -205,7 +205,6 @@ METHOD knh__Int_opNext(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-
 /* @method[CONST] Int! Int.opPrev() */
 
 METHOD knh__Int_opPrev(Ctx *ctx, knh_sfp_t *sfp)
@@ -274,9 +273,9 @@ String* knh_Int_String(Ctx *ctx, Int *o, Mapper *mpr)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%s(OutputStream w, String m) */
 
-void knh_Int__s(Ctx *ctx, Int *b, OutputStream *w, String *m)
+void knh_Int__s(Ctx *ctx, Int *o, OutputStream *w, String *m)
 {
-	knh_write__i(ctx, w, b->value);
+	knh_write_integerfmt(ctx, w, KNH_INTEGER_FMT, (o)->value);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -285,13 +284,27 @@ void knh_Int__s(Ctx *ctx, Int *b, OutputStream *w, String *m)
 void knh_Int__d(Ctx *ctx, Int *o, OutputStream *w, String *m)
 {
 	if(IS_String(m)) {
-		char fmt[40], buf[256];
-		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(m), 0);
-		knh_snprintf(buf, sizeof(buf), fmt, (int)(o)->value);
-		knh_write(ctx, w, B(buf));
+		char fmt[40];
+		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(m), 0, KNH_INTEGER_FMT);
+		knh_write_integerfmt(ctx, w, fmt, (o)->value);
 	}
 	else {
-		knh_write__i(ctx, w, o->value);
+		knh_write_integerfmt(ctx, w, KNH_INTEGER_FMT, (o)->value);
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Int.%u(OutputStream w, String m) */
+
+void knh_Int__u(Ctx *ctx, Int *o, OutputStream *w, String *m)
+{
+	if(IS_String(m)) {
+		char fmt[40];
+		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(m), 0, KNH_UINTEGER_FMT);
+		knh_write_integerfmt(ctx, w, fmt, (o)->value);
+	}
+	else {
+		knh_write_integerfmt(ctx, w, KNH_UINTEGER_FMT, (o)->value);
 	}
 }
 
@@ -301,10 +314,9 @@ void knh_Int__d(Ctx *ctx, Int *o, OutputStream *w, String *m)
 void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m)
 {
 	if(IS_String(m)) {
-		char fmt[40], buf[256];
-		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(m), 1);
-		knh_snprintf(buf, sizeof(buf), fmt, (double)(o)->value);
-		knh_write(ctx, w, B(buf));
+		char fmt[40];
+		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(m), 1, KNH_FLOAT_FMT);
+		knh_write__ffmt(ctx, w, KNH_FLOAT_FMT, (knh_float_t)o->value);
 	}
 	else {
 		knh_write__f(ctx, w, (knh_float_t)o->value);
@@ -314,16 +326,16 @@ void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%x(OutputStream w, String m) */
 
-void knh_Int__x(Ctx *ctx, Int *b, OutputStream *w, String *m)
+void knh_Int__x(Ctx *ctx, Int *o, OutputStream *w, String *m)
 {
-	knh_write__x(ctx, w, b->value);
+	knh_write_integerfmt(ctx, w, KNH_INTEGER_XFMT, o->value);
 }
 
 /* ------------------------------------------------------------------------ */
 
-void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint_t n, int bits)
+void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, int bits)
 {
-	knh_uint_t i, flag = 1 << (bits - 1);
+	knh_uint64_t i, flag = 1 << (bits - 1);
 	for(i = 0; i < (size_t)bits; i++) {
 		if(i > 0 && i % 8 == 0) {
 			knh_putc(ctx, w, ' ');
@@ -342,7 +354,7 @@ void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint_t n, int bits)
 
 void knh_Int__bits(Ctx *ctx, Int *b, OutputStream *w, String *m)
 {
-	knh_write_bits(ctx, w, b->value, sizeof(knh_int_t) * 8);
+	knh_write_bits(ctx, w, b->value, sizeof(knh_integer_t) * 8);
 }
 
 /* ------------------------------------------------------------------------ */
