@@ -90,6 +90,7 @@ knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim)
 
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! String.indexOf(String! s) */
+
 METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
@@ -524,32 +525,103 @@ METHOD knh__String_trim(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] String[] String.split(String delim) */
+/* @method[CONST] String[] String.split(Any delim) */
 
 METHOD knh__String_split(Ctx *ctx, knh_sfp_t *sfp)
 {
-	String *delim = sfp[1].s;
-	if(IS_NULL(delim)) {
-		TODO_THROW(ctx);
+	if(IS_Regex(sfp[1].o)) {
+		KNH_RETURN(ctx, sfp, knh_Regex_split(ctx, (Regex*)sfp[1].o, sfp[0].s));
 	}
-	else if(knh_String_strlen(delim) == 0) {
-		if(knh_String_isASCII(sfp[0].s)) {
-			size_t i, size = knh_String_strlen(sfp[0].s);
-			Array *a = new_Array(ctx, CLASS_String, size);
-			knh_bytes_t ch = knh_String_tobytes(sfp[0].s);
-			ch.len = 1;
-			for(i = 0; i < size; i++) {
-				knh_Array_add(ctx, a, UP(new_String(ctx, ch, sfp[0].s)));
-				ch.buf += 1;
+	else if(IS_String(sfp[1].o)) {
+		int trim = 0;
+		knh_bytes_t base = knh_String_tobytes(sfp[0].s);
+		knh_bytes_t delim = knh_String_tobytes(sfp[1].s);
+		if(delim.len > 1 && delim.buf[delim.len-1] == ' ') {
+			trim = 1;
+			delim.len -=1;
+		}
+		if(delim.len == 0) {
+			if(knh_String_isASCII(sfp[0].s)) {
+				size_t i, n = base.len;
+				Array *a = new_Array(ctx, CLASS_String, n);
+				knh_bytes_t sub = knh_String_tobytes(sfp[0].s);
+				for(i = 0; i < n; i++) {
+					sub.buf = base.buf + i;
+					sub.len = 1;
+					knh_Array_add(ctx, a, UP(new_String(ctx, sub, sfp[0].s)));
+				}
+				KNH_RETURN(ctx, sfp, a);
+			}
+			else {
+				size_t i, n = knh_bytes_mlen(base);
+				Array *a = new_Array(ctx, CLASS_String, n);
+				for(i = 0; i < n; i++) {
+					knh_bytes_t sub = knh_bytes_mofflen(base, n, 1);
+					knh_Array_add(ctx, a, UP(new_String(ctx, sub, sfp[0].s)));
+				}
+				KNH_RETURN(ctx, sfp, a);
+			}
+		}else {
+			Array *a = new_Array(ctx, CLASS_String, 8);
+			while(1) {
+				knh_index_t loc = knh_bytes_indexOf(base, delim);
+				if(loc == -1) {
+					if(knh_bytes_equals(base, knh_String_tobytes(sfp[0].s))) {
+						knh_Array_add(ctx, a, UP(sfp[0].s));
+					}
+					else {
+						knh_Array_add(ctx, a, UP(new_String(ctx, base, sfp[0].s)));
+					}
+					break;
+				}
+				if(loc == 0) {
+					knh_Array_add(ctx, a, UP(TS_EMPTY));
+				}
+				else {
+					knh_Array_add(ctx, a, UP(new_String(ctx, knh_bytes_first(base, loc), sfp[0].s)));
+				}
+				base.buf = base.buf + loc + delim.len;
+				base.len = base.len - loc - delim.len;
+				if(trim) {
+					while(isspace(base.buf[0])) {
+						base.buf = base.buf + 1;
+						base.len = base.len - 1;
+					}
+				}
 			}
 			KNH_RETURN(ctx, sfp, a);
 		}
-		else {
-			TODO_THROW(ctx);
-		}
 	}
-	else {
-		TODO_THROW(ctx);
+	else {  /* sfp[1].o == null */
+		knh_bytes_t base = knh_String_tobytes(sfp[0].s);
+		Array *a = new_Array(ctx, CLASS_String, 8);
+		size_t loc;
+		while(1) {
+			while(isspace(base.buf[0])) {
+				base.buf = base.buf + 1;
+				base.len = base.len - 1;
+			}
+			if(base.buf[0] == 0) break;
+			for(loc = 0; loc < base.len; loc++) {
+				int ch = base.buf[loc];
+				if(isspace(ch)) break;
+			}
+			if(loc == base.len) {
+				if(knh_bytes_equals(base, knh_String_tobytes(sfp[0].s))) {
+					knh_Array_add(ctx, a, UP(sfp[0].s));
+				}
+				else {
+					knh_Array_add(ctx, a, UP(new_String(ctx, base, sfp[0].s)));
+				}
+				break;
+			} else {
+				knh_Array_add(ctx, a, UP(new_String(ctx, knh_bytes_first(base, loc), NULL /*sfp[0].s*/)));
+			}
+			base.buf = base.buf + loc;
+			base.len = base.len - loc;
+		}
+
+		KNH_RETURN(ctx, sfp, a);
 	}
 }
 
