@@ -489,11 +489,6 @@ void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid,
 void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
 void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
 void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
-/* ../class/konoha/knh_iodrv.c */
-knh_iodrv_t *knh_System_getIODriver(Ctx *ctx, knh_bytes_t name);
-knh_iodrv_t knh_System_getDefaultIODriver();
-knh_iodrv_t knh_System_getStdIODriver();
-void KNHINIT init_IO(Ctx *ctx);
 /* ../class/konoha/knh_Iterator.c */
 void knh_Iterator_struct_init(Ctx *ctx, knh_Iterator_struct *b, int init, Object *cs);
 void knh_Iterator_struct_copy(Ctx *ctx, knh_Iterator_struct *b, knh_Iterator_struct *b2);
@@ -675,8 +670,12 @@ METHOD knh__Range_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Range_new__slice(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Range_new__offset(Ctx *ctx, knh_sfp_t *sfp);
 /* ../class/konoha/knh_Regex.c */
-void KNHINIT init_Regex(Ctx *ctx);
 Regex *new_Regex(Ctx *ctx, String *pattern);
+void knh_Regex_traverse(Ctx *ctx, Regex *o, f_traverse ftr);
+int knh_String_opMatch(Ctx *ctx, String *o, Regex *re);
+METHOD knh__String_opMatch(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Regex_opMatch(Ctx *ctx, knh_sfp_t *sfp);
+Array *knh_Regex_split(Ctx *ctx, Regex *o, String *s);
 void knh_Regex__s(Ctx *ctx, Regex *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ResultSet.c */
 void knh_ResultSet_struct_init(Ctx *ctx, knh_ResultSet_struct *b, int init, Object *cs);
@@ -1033,6 +1032,14 @@ void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../konoha/deps/cygwin/filesystem__cygwin.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
+/* ../konoha/deps/knh_driver_io.c */
+knh_iodrv_t *knh_System_getIODriver(Ctx *ctx, knh_bytes_t name);
+knh_iodrv_t knh_System_getDefaultIODriver();
+knh_iodrv_t knh_System_getStdIODriver();
+void KNHINIT init_IO(Ctx *ctx);
+/* ../konoha/deps/knh_driver_regex.c */
+knh_regex_drvapi_t *knh_System_getRegexDriver(Ctx *ctx, knh_bytes_t name);
+void KNHINIT init_Regex(Ctx *ctx);
 /* ../konoha/deps/linux/filesystem__linux.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
