@@ -89,7 +89,7 @@ static char* knh_token_array_tochar[] = {
     "&=",  /* bitande */ 
     "?\?=",  /* ALTLET */ 
     "?",  /* QUESTION */ 
-    "..",  /* SUBSETE */ 
+    "..",  /* Itr */ 
     "..<",  /* SUBSET */ 
     "..+",  /* OFFSET */ 
     ":",  /* COLON */ 
@@ -109,6 +109,7 @@ static char* knh_token_array_tochar[] = {
     "<=",  /* Lte */ 
     ">",  /* Gt */ 
     ">=",  /* Gte */ 
+    "=~",  /* Match */ 
     "|",  /* Lor */ 
     "%%",  /* Fmt */ 
     "<<",  /* Lshift */ 
@@ -213,7 +214,7 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* bitande */ 
     METHODN_NONAME,  /* ALTLET */ 
     METHODN_NONAME,  /* QUESTION */ 
-    METHODN_NONAME,  /* SUBSETE */ 
+    METHODN_opItr,  /* Itr */ 
     METHODN_NONAME,  /* SUBSET */ 
     METHODN_NONAME,  /* OFFSET */ 
     METHODN_NONAME,  /* COLON */ 
@@ -233,6 +234,7 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_opLte,  /* Lte */ 
     METHODN_opGt,  /* Gt */ 
     METHODN_opGte,  /* Gte */ 
+    METHODN_opMatch,  /* Match */ 
     METHODN_opLor,  /* Lor */ 
     METHODN_opFmt,  /* Fmt */ 
     METHODN_opLshift,  /* Lshift */ 
@@ -337,10 +339,10 @@ static int knh_token_array_getOpPriority[] = {
     0,  /* bitande */ 
     0,  /* ALTLET */ 
     2,  /* QUESTION */ 
-    2,  /* SUBSETE */ 
-    2,  /* SUBSET */ 
-    2,  /* OFFSET */ 
-    2,  /* COLON */ 
+    2,  /* Itr */ 
+    99,  /* SUBSET */ 
+    99,  /* OFFSET */ 
+    99,  /* COLON */ 
     2,  /* ALT */ 
     5,  /* OR */ 
     6,  /* AND */ 
@@ -357,6 +359,7 @@ static int knh_token_array_getOpPriority[] = {
     9,  /* Lte */ 
     9,  /* Gt */ 
     9,  /* Gte */ 
+    9,  /* Match */ 
     11,  /* Lor */ 
     12,  /* Fmt */ 
     15,  /* Lshift */ 
@@ -461,7 +464,7 @@ static int knh_token_array_getOpSize[] = {
     0,  /* bitande */ 
     0,  /* ALTLET */ 
     0,  /* QUESTION */ 
-    0,  /* SUBSETE */ 
+    1,  /* Itr */ 
     0,  /* SUBSET */ 
     0,  /* OFFSET */ 
     0,  /* COLON */ 
@@ -481,6 +484,7 @@ static int knh_token_array_getOpSize[] = {
     2,  /* Lte */ 
     2,  /* Gt */ 
     2,  /* Gte */ 
+    2,  /* Match */ 
     0,  /* Lor */ 
     2,  /* Fmt */ 
     0,  /* Lshift */ 
@@ -585,7 +589,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     0,  /* bitande */ 
     0,  /* ALTLET */ 
     0,  /* QUESTION */ 
-    0,  /* SUBSETE */ 
+    0,  /* Itr */ 
     0,  /* SUBSET */ 
     0,  /* OFFSET */ 
     0,  /* COLON */ 
@@ -605,6 +609,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     0,  /* Lte */ 
     0,  /* Gt */ 
     0,  /* Gte */ 
+    0,  /* Match */ 
     0,  /* Lor */ 
     0,  /* Fmt */ 
     0,  /* Lshift */ 
@@ -732,7 +737,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line
     break;
     case '.':
         if(ISB(t, "...")) { tt = TT_DOTS; break; }
-        if(ISB(t, "..")) { tt = TT_SUBSETE; break; }
+        if(ISB(t, "..")) { tt = TT_ITR; break; }
         if(ISB(t, "..<")) { tt = TT_SUBSET; break; }
         if(ISB(t, "..+")) { tt = TT_OFFSET; break; }
     break;
@@ -756,6 +761,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line
         if(ISB(t, "=")) { tt = TT_LET; break; }
         if(ISB(t, "===")) { tt = TT_IS; break; }
         if(ISB(t, "==")) { tt = TT_EQ; break; }
+        if(ISB(t, "=~")) { tt = TT_MATCH; break; }
     break;
     case '>':
         if(ISB(t, ">>=")) { tt = TT_RSHIFTE; break; }
@@ -973,6 +979,9 @@ int knh_bytes_istoken(knh_bytes_t t, int ch)
     case '|':
         if(ISB(t, "|")) { return 1; }
         return 0; 
+    case '~':
+        if(ISB(t, "=")) { return 1; }
+        return 0; 
     /* built-in */
     }
     return 0;
@@ -1762,7 +1771,7 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
         break;
     case TT_QUESTION:  /* QUESTION */
         break;
-    case TT_SUBSETE:  /* SUBSETE */
+    case TT_ITR:  /* Itr */
         break;
     case TT_SUBSET:  /* SUBSET */
         break;
@@ -1803,6 +1812,8 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
         break;
     case TT_GTE:  /* Gte */
         break;
+    case TT_MATCH:  /* Match */
+        break;
     case TT_LOR:  /* Lor */
         tc->c -= 1;
         return new_StmtFUNCEXPR(ctx, tc);
